library(coda)
library(plyr)
library(ggplot2)
library(phangorn)
library(distory)
library(reshape2)
library(rwty)
library(gridExtra)
library(viridis)
setwd("~/Dropbox/Projects_Current/Tree_ESS/R")
source("functions.r")

processors = 4


##################################################################
##################################################################
#######                     ANALYSIS 1                    ########


##################################################################
# Figure 1

### Unimodal simulations ###

length = 1000
ess.reps = 100
n.taxa = 50

# simulate the trees
s1 = simulate.tree.mcmc(n.taxa, length, 1, "~/Dropbox/Projects_Current/Tree_ESS/output/s1.nex")
s2 = simulate.tree.mcmc(n.taxa, length, 2, "~/Dropbox/Projects_Current/Tree_ESS/output/s2.nex")
s3 = simulate.tree.mcmc(n.taxa, length, 5, "~/Dropbox/Projects_Current/Tree_ESS/output/s3.nex")
s4 = simulate.tree.mcmc(n.taxa, length, 10, "~/Dropbox/Projects_Current/Tree_ESS/output/s4.nex")
s5 = simulate.tree.mcmc(n.taxa, length, 20, "~/Dropbox/Projects_Current/Tree_ESS/output/s5.nex")
s6 = simulate.tree.mcmc(n.taxa, length, 50, "~/Dropbox/Projects_Current/Tree_ESS/output/s6.nex")

s.chains = list(s1, s2, s3, s4, s5, s6)
names(s.chains) = c('01 SPR move', '02 SPR moves', '05 SPR moves', '10 SPR moves', '20 SPR moves', '50 SPR moves')
fig1a = makeplot.autocorr(s.chains, facet = TRUE, autocorr.intervals = 100)
fig1b = makeplot.topology.trace(s.chains, facet = TRUE, approx.ess = FALSE)

### Unimodal simulations ###
# the two starting sets
set1 <- vector("list", 10)
start.tree <- rtree(n.taxa, rooted = FALSE)
set1[[1]] = start.tree
for(i in 2:10){
  set1[[i]] <- rSPR(set1[[1]], moves=1)
}

set2 <- vector("list", 10)
set2[[1]] = rSPR(start.tree, moves=50)
for(i in 2:10){
  set2[[i]] <- rSPR(set2[[1]], moves=1)
}

m1 = simulate.tree.mcmc.mixing(set1, set2, length, 0.01, "~/Dropbox/Projects_Current/Tree_ESS/output/m1.nex")
m2 = simulate.tree.mcmc.mixing(set1, set2, length, 0.1, "~/Dropbox/Projects_Current/Tree_ESS/output/m2.nex")
m3 = simulate.tree.mcmc.mixing(set1, set2, length, 0.2, "~/Dropbox/Projects_Current/Tree_ESS/output/m3.nex")
m4 = simulate.tree.mcmc.mixing(set1, set2, length, 0.3, "~/Dropbox/Projects_Current/Tree_ESS/output/m4.nex")
m5 = simulate.tree.mcmc.mixing(set1, set2, length, 0.4, "~/Dropbox/Projects_Current/Tree_ESS/output/m5.nex")
m6 = simulate.tree.mcmc.mixing(set1, set2, length, 0.5, "~/Dropbox/Projects_Current/Tree_ESS/output/m6.nex")

m.chains = list(m1, m2, m3, m4, m5, m6)
names(m.chains) = c('M = 0.01', 'M = 0.1', 'M = 0.2', 'M = 0.3', 'M = 0.4', 'M = 0.5')
fig1c = makeplot.autocorr(m.chains, facet = TRUE, autocorr.intervals = 100)
fig1d = makeplot.topology.trace(m.chains, facet = TRUE, approx.ess = FALSE)


quartz(width = 12, height = 12)
fig1 = grid.arrange(fig1a$autocorr.plot, 
                    fig1b$topology.trace.plot, 
                    fig1c$autocorr.plot, 
                    fig1d$topology.trace.plot, 
                    ncol = 2)
ggsave(file = "../Figures/Figure1_raw.pdf", fig1)


##################################################################
# Figure 2
# comparison of approx. and pseudo ESS for 12 simulated datasets

# get the pseudo ESS's for the simulated data
s1.pseudo.ess <- unlist(pseudo.ess(s1, n = ess.reps))
s2.pseudo.ess <- unlist(pseudo.ess(s2, n = ess.reps))
s3.pseudo.ess <- unlist(pseudo.ess(s3, n = ess.reps))
s4.pseudo.ess <- unlist(pseudo.ess(s4, n = ess.reps))
s5.pseudo.ess <- unlist(pseudo.ess(s5, n = ess.reps))
s6.pseudo.ess <- unlist(pseudo.ess(s6, n = ess.reps))

m1.pseudo.ess <- unlist(pseudo.ess(m1, n = ess.reps))
m2.pseudo.ess <- unlist(pseudo.ess(m2, n = ess.reps))
m3.pseudo.ess <- unlist(pseudo.ess(m3, n = ess.reps))
m4.pseudo.ess <- unlist(pseudo.ess(m4, n = ess.reps))
m5.pseudo.ess <- unlist(pseudo.ess(m5, n = ess.reps))
m6.pseudo.ess <- unlist(pseudo.ess(m6, n = ess.reps))

# get the approximate ESS's for the simulated data
s1.approx.ess <- topological.approx.ess(s1)
s2.approx.ess <- topological.approx.ess(s2)
s3.approx.ess <- topological.approx.ess(s3)
s4.approx.ess <- topological.approx.ess(s4)
s5.approx.ess <- topological.approx.ess(s5)
s6.approx.ess <- topological.approx.ess(s6)

m1.approx.ess <- topological.approx.ess(m1)
m2.approx.ess <- topological.approx.ess(m2)
m3.approx.ess <- topological.approx.ess(m3)
m4.approx.ess <- topological.approx.ess(m4)
m5.approx.ess <- topological.approx.ess(m5)
m6.approx.ess <- topological.approx.ess(m6)

# unattractive way to put the data together
s.pseudo = data.frame(rbind(s1.pseudo.ess, s2.pseudo.ess, s3.pseudo.ess, s4.pseudo.ess, s5.pseudo.ess, s6.pseudo.ess))
names(s.pseudo) = c('ess', 'ci.upper', 'ci.lower')
s.pseudo$SPR.moves = c(1, 2, 5, 10, 20, 50)
s.pseudo$type = 'Pseudo ESS'
rownames(s.pseudo) = NULL
s.approx = rbind(s1.approx.ess, s2.approx.ess, s3.approx.ess, s4.approx.ess, s5.approx.ess, s6.approx.ess)
s.approx = data.frame('ess' = s.approx[,2], ci.upper = NA, ci.lower = NA)
s.approx$SPR.moves = c(1, 2, 5, 10, 20, 50)
s.approx$type = "Approximate ESS"
rownames(s.approx) = NULL
s.dat = data.frame(rbind(s.pseudo, s.approx))

m.pseudo = data.frame(rbind(m1.pseudo.ess, m2.pseudo.ess, m3.pseudo.ess, m4.pseudo.ess, m5.pseudo.ess, m6.pseudo.ess))
names(m.pseudo) = c('ess', 'ci.upper', 'ci.lower')
m.pseudo$M = c(0.01, 0.1, 0.2, 0.3, 0.4, 0.5)
m.pseudo$type = 'Pseudo ESS'
rownames(m.pseudo) = NULL
m.approx = rbind(m1.approx.ess, m2.approx.ess, m3.approx.ess, m4.approx.ess, m5.approx.ess, m6.approx.ess)
m.approx = data.frame('ess' = m.approx[,2], ci.upper = NA, ci.lower = NA)
m.approx$M = c(0.01, 0.1, 0.2, 0.3, 0.4, 0.5)
m.approx$type = "Approximate ESS"
rownames(m.approx) = NULL
m.dat = data.frame(rbind(m.pseudo, m.approx))

write.csv(s.dat, file = "../output/fig2a.csv")
write.csv(m.dat, file = "../output/fig2b.csv")


fig2a.dat <- read.csv(file = "../output/fig2a.csv", row.names=1)
fig2b.dat <- read.csv(file = "../output/fig2b.csv", row.names=1)

fig2a = ggplot(fig2a.dat, aes(x=SPR.moves, y=ess, colour = type)) + 
  geom_point() + geom_line() +
  geom_linerange(aes(ymin=ci.lower, ymax=ci.upper)) +
  xlab("Number of SPR moves between samples") +
  ylab("Approximate or Pseudo ESS") + 
  ylim(c(0, 1200)) + 
  ggtitle("(A) Unimodal MCMC simulations")

fig2b = ggplot(fig2b.dat, aes(x=M, y=ess, colour = type)) + 
  geom_point() + geom_line() +
  geom_linerange(aes(ymin=ci.lower, ymax=ci.upper)) +
  xlab("M (probability of switching modes between sequential samples)") +
  ylab("Approximate or Pseudo ESS") + 
  ylim(c(0, 1200)) +
  ggtitle("(B) Bimodal MCMC simulations")

quartz(width = 8, height = 8)
fig2 = grid.arrange(fig2a, fig2b, ncol=1)
ggsave(file = "../Figures/Figure2_raw.pdf", fig2)



##################################################################
##################################################################
#######                     ANALYSIS 2                    ########

##################################################################
# Figure 3, much as for Figure 1, but with 6 empirical datasets
# note we do not use the Brookesia dataset, because unlike other datasets in the same paper,
# it has only 1500 trees (instead of 4004) in the posterior sample. 

# load the data from file, and take the last 1001 trees from each
# the last 1001 trees are each from a single run 
# the original papers combines 4 runs into a single file
d1 <- read.user.trees(infilename="../empirical_datasets/Scantulbury_2013/rawtrees/post_Cophyline_100_yule_4runs_10milburn.trees", outfilename = '~/Dropbox/Projects_Current/Tree_ESS/output/d1.nex')
d2 <- read.user.trees(infilename="../empirical_datasets/Scantulbury_2013/rawtrees/post_Gephyromantis_rooted_YULE_4runs_10milburn.trees", outfilename = '~/Dropbox/Projects_Current/Tree_ESS/output/d2.nex')
d3 <- read.user.trees(infilename="../empirical_datasets/Scantulbury_2013/rawtrees/post_Heterixalus_35tax_combined_yule_4runs_10milburn.trees", outfilename = '~/Dropbox/Projects_Current/Tree_ESS/output/d3.nex')
d4 <- read.user.trees(infilename="../empirical_datasets/Scantulbury_2013/rawtrees/post_Paroedura_100_yule_combined_4runs_10milburn.trees", outfilename = '~/Dropbox/Projects_Current/Tree_ESS/output/d4.nex')
d5 <- read.user.trees(infilename="../empirical_datasets/Scantulbury_2013/rawtrees/post_Phelsuma_100_yule_4runs_10milburn.trees", outfilename = '~/Dropbox/Projects_Current/Tree_ESS/output/d5.nex')
d6 <- read.user.trees(infilename="../empirical_datasets/Scantulbury_2013/rawtrees/post_Uroplatus_100_yule_4runs_10milburn.trees", outfilename = '~/Dropbox/Projects_Current/Tree_ESS/output/d6.nex')

d.chains = list(d1, d2, d3, d4, d5, d6)
names(d.chains) = c('Cophyline', 'Gephyromantis', 'Heterixalus', 'Paroedura', 'Phelsuma', 'Uroplatus')
fig3a = makeplot.autocorr(d.chains, facet = TRUE, free_y = TRUE, autocorr.intervals = 100)
fig3b = makeplot.topology.trace(d.chains, facet = TRUE, free_y = TRUE, independent.chains = TRUE, approx.ess = FALSE)

fig3a = fig3a$autocorr.plot + ggtitle("(A) Toppological autocorrelation plot")
fig3b = fig3b$topology.trace.plot + ggtitle("(B) Tree topology trace")
quartz(width = 12, height = 6)
fig3 = grid.arrange(fig3a, fig3b, ncol = 2)
ggsave(file = "../Figures/Figure3_raw.pdf", fig3)



##################################################################
# Figure 4, comparison of approx. and pseudo ESS for 6 simulated datasets

# get the pseudo ESS's for the simulated data
d1.pseudo.ess <- unlist(pseudo.ess(d1, n = ess.reps))
d2.pseudo.ess <- unlist(pseudo.ess(d2, n = ess.reps))
d3.pseudo.ess <- unlist(pseudo.ess(d3, n = ess.reps))
d4.pseudo.ess <- unlist(pseudo.ess(d4, n = ess.reps))
d5.pseudo.ess <- unlist(pseudo.ess(d5, n = ess.reps))
d6.pseudo.ess <- unlist(pseudo.ess(d6, n = ess.reps))

# get the approximate ESS's for the simulated data
d1.approx.ess <- topological.approx.ess(d1)
d2.approx.ess <- topological.approx.ess(d2)
d3.approx.ess <- topological.approx.ess(d3)
d4.approx.ess <- topological.approx.ess(d4)
d5.approx.ess <- topological.approx.ess(d5)
d6.approx.ess <- topological.approx.ess(d6)

d.pseudo = data.frame(rbind(d1.pseudo.ess, d2.pseudo.ess, d3.pseudo.ess, d4.pseudo.ess, d5.pseudo.ess, d6.pseudo.ess))
names(d.pseudo) = c('ess', 'ci.upper', 'ci.lower')
d.pseudo$dataset = c('Cophyline', 'Gephyromantis', 'Heterixalus', 'Paroedura', 'Phelsuma', 'Uroplatus')
d.pseudo$type = 'Pseudo ESS'
rownames(d.pseudo) = NULL


d.approx = rbind(d1.approx.ess, d2.approx.ess, d3.approx.ess, d4.approx.ess, d5.approx.ess, d6.approx.ess)
d.approx = data.frame('ess' = d.approx[,2], ci.upper = NA, ci.lower = NA)
d.approx$dataset = c('Cophyline', 'Gephyromantis', 'Heterixalus', 'Paroedura', 'Phelsuma', 'Uroplatus')
d.approx$type = "Approximate ESS"
rownames(d.approx) = NULL

d.dat = data.frame(rbind(d.pseudo, d.approx))
write.csv(d.dat, file = "../output/fig4.csv")

fig4 = ggplot(d.dat, aes(x=dataset, y=ess, colour = type)) + 
  geom_linerange(aes(ymin=ci.lower, ymax=ci.upper)) +
  geom_point(aes(shape = type)) + ylim(c(0,1000)) +
  xlab("Empirical dataset") +
  ylab("Approximate or Pseudo ESS")

quartz(width = 8, height = 4)
fig4
ggsave(file = "../Figures/Figure4_raw.pdf", fig4)


##################################################################
##################################################################
#######                     ANALYSIS 3                    ########


##################################################################
# Figure 5, simulations across a broad range of parameter values
# simulating unimodal posterior distributions
# Set up simulations with the following conditions
# NB: file names might look odd, because simulations were run on 
# a server, then plots generated on a desktop.

n.taxa <- c(5, 20, 100)
n.sprs <- c(1:200)
reps <- c(1)
chain.length <- c(1000)

# ARGH!
options(stringsAsFactors = FALSE)

params <- expand.grid("n.taxa" = n.taxa, "n.trees" = chain.length, "n.sprs" = n.sprs, "rep" = reps)

# Now run the simulations, and calculate the ESS's
fig5.simulation.results <- run.simulations(params, processors = processors, folder = "~/data/tree_ess/")

# reload the data and do some munging (the filenames change because I do the simulatios on a server)
write.csv(fig5.simulation.results, file = "~/data/tree_ess/fig5.csv")

fig5.dat <- read.csv(file = "../output/fig5.csv", row.names=1)

fig5.datmelt1 = melt(fig5.dat, id.vars = c("taxa", "trees", "sprs", "rep"), measure.vars = c("pseudo.ESS.PD", "pseudo.ESS.RF", "approx.ESS.PD", "approx.ESS.RF"))
names(fig5.datmelt1) = c("taxa", "trees", "sprs", "rep", "type", "ESS")

fig5.datmelt2 = melt(fig5.dat, id.vars = c("taxa", "trees", "sprs", "rep"), measure.vars = c("approx.ESS.PD.operator", "approx.ESS.RF.operator"))
fig5.datmelt2$type = NA
fig5.datmelt2$type[fig5.datmelt2$variable=="approx.ESS.PD.operator"] = "approx.ESS.PD"
fig5.datmelt2$type[fig5.datmelt2$variable=="approx.ESS.RF.operator"] = "approx.ESS.RF"
names(fig5.datmelt2) = c("taxa", "trees", "sprs", "rep", "variable", "operator", "type")
fig5.datmelt2 = fig5.datmelt2[,-5]

fig5.datmelt = merge(fig5.datmelt1, fig5.datmelt2, by = c("taxa", "trees", "sprs", "rep", "type"), all=TRUE)
t1 = strsplit(as.character(fig5.datmelt$type), split=".", fixed = TRUE)
fig5.datmelt$ESS.type = rapply(t1, function(x) head(x, 1))
fig5.datmelt$treedist = rapply(t1, function(x) tail(x, 1))

# pseudo ESS are all '='
fig5.datmelt$operator[is.na(fig5.datmelt$operator)] = '='

# pretty up the labels for the graph
fig5.datmelt$ESS.type[which(fig5.datmelt$ESS.type == 'pseudo')] = 'Pseudo ESS'
fig5.datmelt$ESS.type[which(fig5.datmelt$ESS.type == 'approx')] = 'Approximate ESS'

fig5.datmelt$treedist[which(fig5.datmelt$treedist == 'PD')] = 'Path Difference'
fig5.datmelt$treedist[which(fig5.datmelt$treedist == 'RF')] = 'Robinson-Foulds Distance'

fig5.datmelt$taxa[which(fig5.datmelt$taxa == '5')] = '5 taxon tree'
fig5.datmelt$taxa[which(fig5.datmelt$taxa == '20')] = '20 taxon tree'
fig5.datmelt$taxa[which(fig5.datmelt$taxa == '100')] = '100 taxon tree'

fig5.datmelt$taxa = factor(fig5.datmelt$taxa, levels = c("5 taxon tree", "20 taxon tree", "100 taxon tree"))

fig5 <- ggplot(fig5.datmelt, aes(x=sprs, y=ESS)) + 
  geom_point(size = 1, aes(colour = ESS.type), alpha = 0.5) + 
  facet_grid(treedist ~ taxa) + expand_limits(y=0) +
  xlab("Number of SPR moves between trees in the MCMC") +
  ylab("Approximate or Pseudo ESS")

quartz(width = 8, height = 4)
fig5
ggsave(file = "../Figures/Figure5_raw.pdf", fig5)

##################################################################
# Figure 6, compare the two ESS estimates on the unimodal simulations

fig6.dat = fig5.dat

fig6base <- ggplot(fig6.dat) + 
  geom_abline(intercept = 0, slope = 1, linetype = 'dotted') +
  scale_x_continuous(breaks = c(0, 200, 400, 600, 800, 1000, 1200), limits = c(0, 1250)) +
  scale_y_continuous(breaks = c(0, 200, 400, 600, 800, 1000, 1200), limits = c(0, 1250))
  
fig6a <- fig6base + 
  geom_point(aes(x = approx.ESS.PD, y = pseudo.ESS.PD), alpha = 0.5, size = 0.75) +
  xlab('Approximate ESS (Path Difference)') +
  ylab('Pseudo ESS (Path Difference)')                                            

fig6b <- fig6base + 
  geom_point(aes(x = approx.ESS.RF, y = pseudo.ESS.RF), alpha = 0.5, size = 0.75) +
  xlab('Approximate ESS (RF Distance)') +
  ylab('Pseudo ESS (RF Distance)')

fig6c <- fig6base + 
  geom_point(aes(x = approx.ESS.PD, y = approx.ESS.RF), alpha = 0.5, size = 0.75) +
  xlab('Approximate ESS (Path Difference)') +
  ylab('Approximate ESS (RF Distance)')

fig6d <- fig6base + 
  geom_point(aes(x = pseudo.ESS.PD, y = pseudo.ESS.RF), alpha = 0.5, size = 0.7) +
  xlab('Pseudo ESS (Path Difference)') +
  ylab('Pseudo ESS (RF Distance)')

quartz(width = 8, height = 8)
fig6 = grid.arrange(fig6a, fig6b, fig6c, fig6d, ncol=2)
ggsave(file = "../Figures/Figure6_raw.pdf", fig6)


##################################################################
# Figure 7, simulations across parameters with bimodal posteriors

# The two sets of trees come from above
n.taxa = 50
spr.moves = 50
n.trees = 1000

# run the simulations
folder = "~/data/tree_ess/"
ms = seq(0, 0.5, by = 0.005)
fig7.matrix = mclapply(ms, run.mixing.simulation, set1, set2, folder, mc.cores = processors)
fig7.df <- data.frame(t(data.frame(fig7.matrix)))
rownames(fig7.df) = NULL
names(fig7.df) <- c("M", "pseudo.ESS.PD", "approx.ESS.PD.operator", "approx.ESS.PD", "pseudo.ESS.RF", "approx.ESS.RF.operator", "approx.ESS.RF")
write.csv(fig7.df, file = "~/data/tree_ess/fig7.csv")

# now we draw the figure
fig7.dat = read.csv("../output/fig7.csv")

fig7.datmelt1 = melt(fig7.dat, id.vars = c("M"), measure.vars = c("pseudo.ESS.PD", "pseudo.ESS.RF", "approx.ESS.PD", "approx.ESS.RF"))
names(fig7.datmelt1) = c("M", "type", "ESS")

fig7.datmelt2 = melt(fig7.dat, id.vars = c("M"), measure.vars = c("approx.ESS.PD.operator", "approx.ESS.RF.operator"))
fig7.datmelt2$type = NA

fig7.datmelt2$type[fig7.datmelt2$variable=="approx.ESS.PD.operator"] = "approx.ESS.PD"
fig7.datmelt2$type[fig7.datmelt2$variable=="approx.ESS.RF.operator"] = "approx.ESS.RF"
names(fig7.datmelt2) = c("M", "variable", "operator", "type")

fig7.datmelt = merge(fig7.datmelt1, fig7.datmelt2, by = c("M", "type"), all=TRUE)
t1 = strsplit(as.character(fig7.datmelt$type), split=".", fixed = TRUE)
fig7.datmelt$ESS.type = rapply(t1, function(x) head(x, 1))
fig7.datmelt$treedist = rapply(t1, function(x) tail(x, 1))

# pseudo ESS are all '='
fig7.datmelt$operator[is.na(fig7.datmelt$operator)] = '='

# pretty up the labels for the graph
fig7.datmelt$ESS.type[which(fig7.datmelt$ESS.type == 'pseudo')] = 'Pseudo ESS'
fig7.datmelt$ESS.type[which(fig7.datmelt$ESS.type == 'approx')] = 'Approximate ESS'

fig7.datmelt$treedist[which(fig7.datmelt$treedist == 'PD')] = 'Path Difference'
fig7.datmelt$treedist[which(fig7.datmelt$treedist == 'RF')] = 'Robinson-Foulds Distance'



fig7base <- ggplot(fig7.dat, aes(colour = M)) + 
  geom_abline(intercept = 0, slope = 1, linetype = 'dotted') +
  scale_colour_gradientn(colours = viridis(256))

fig7a <- fig7base + 
  geom_point(aes(x = approx.ESS.PD, y = pseudo.ESS.PD)) +
  xlab('Approximate ESS (Path Difference)') +
  ylab('Pseudo ESS (Path Difference)') +
  scale_x_continuous(breaks = seq(0, 1000, 250)) +
  scale_y_continuous(breaks = seq(0, 1250, 250))

fig7b <- fig7base + 
  geom_point(aes(x = approx.ESS.RF, y = pseudo.ESS.RF)) +
  xlab('Approximate ESS (RF Distance)') +
  ylab('Pseudo ESS (RF Distance)') +
  scale_x_continuous(breaks = seq(0, 1000, 250)) +
  scale_y_continuous(breaks = seq(0, 1000, 250))

fig7c <- fig7base + 
  geom_point(aes(x = approx.ESS.PD, y = approx.ESS.RF)) +
  xlab('Approximate ESS (Path Difference)') +
  ylab('Approximate ESS (RF Distance)') +
  scale_x_continuous(breaks = seq(0, 1000, 250)) +
  scale_y_continuous(breaks = seq(0, 1000, 250))

fig7d <- fig7base + 
  geom_point(aes(x = pseudo.ESS.PD, y = pseudo.ESS.RF)) +
  xlab('Pseudo ESS (Path Difference)') +
  ylab('Pseudo ESS (RF Distance)') +
  scale_x_continuous(breaks = seq(0, 1250, 250)) +
  scale_y_continuous(breaks = seq(0, 1000, 250))

quartz(width = 8, height = 8)
fig7 = grid.arrange(fig7a, fig7b, fig7c, fig7d, ncol=2)
ggsave(file = "../Figures/Figure7_forlegend.pdf", fig7)

quartz(width = 8, height = 8)
fig7a = fig7a + guides(colour=FALSE)
fig7b = fig7b + guides(colour=FALSE)
fig7c = fig7c + guides(colour=FALSE)
fig7d = fig7d + guides(colour=FALSE)
fig7 = grid.arrange(fig7a, fig7b, fig7c, fig7d, ncol=2)
ggsave(file = "../Figures/Figure7_raw.pdf", fig7)

